@@ -7,7 +7,7 @@ from .edits import *
 from .version import __version__, VERSION_STRING
 from . import bounds, edits, expressions, fibonacci, formatter, levenshtein, matching, printer, \
                                                                search, sequences, tree, utils
-from . import csv, json, xml, yaml
+from . import csv, json, xml, yaml, plist
 
 import inspect
 
