@@ -241,6 +241,8 @@ def main(argv=None) -> int:
         mimetypes.suffix_map['.yaml'] = '.yml'
     if '.json5' not in mimetypes.types_map:
         mimetypes.add_type('application/json5', '.json5')
+    if '.plist' not in mimetypes.types_map:
+        mimetypes.add_type('application/x-plist', '.plist')
 
     if args.from_mime is not None:
         from_mime = args.from_mime
